import { AnnotationPanel } from '../../components/annotation/AnnotationPanel';
import { DocumentAnnotationView } from '../../components/annotation/DocumentAnnotationView';
import { TagPanel } from '../../components/annotation/TagPanel';
import { MainLayout } from '../../layouts/MainLayout';
import 'antd/dist/antd.css';
import styles from '/styles/Annotation.module.scss';
import AnnotationProvider from '../../contexts/AnnotationContext';
import { useRouter } from 'next/router';

/**
 * Creates an annotation screen.
 * @returns The annotation screen.
 */
function Annotation() {
    const router = useRouter();
    const { id } = router.query;

    if (!id || typeof id !== 'string') {
        /*(async () => {
            await router.push('/documents');
        })(); // TODO*/

        return <p>Načítání...</p>;
    }

    const annotationId: string = Array.isArray(id) ? id[0] : id;

    return (
        <AnnotationProvider annotationId={annotationId}>
            <MainLayout>
                <div className={styles.layoutWrapper}>
                    <div className={styles.tags}>
                        <TagPanel />
                    </div>
                    <div className={styles.document}>
                        <DocumentAnnotationView />
                    </div>
                    <div className={styles.annotations}>
                        <AnnotationPanel />
                    </div>
                </div>
            </MainLayout>
        </AnnotationProvider>
    );
}

export default Annotation;
